@@ -5,6 +5,7 @@ import os
 from pathlib import Path
 from typing import List, Optional, Union
 
+import httpx
 import typer
 
 from . import __version__
@@ -29,7 +30,7 @@ def main(
     [bold blue]Kit[/] - A modular toolkit for LLM-powered codebase understanding.
 
     [bold yellow]🤖 AI-Powered Commands:[/]
-    • [cyan]review[/]     - AI code reviews for GitHub PRs
+    • [cyan]review[/]     - AI code reviews for GitHub PRs or local diffs
     • [cyan]summarize[/]  - Quick PR summaries for triage
     • [cyan]commit[/]     - Generate intelligent commit messages
 
@@ -40,6 +41,11 @@ def main(
     • [cyan]search-semantic[/] - AI-powered semantic code search
     • [cyan]file-tree[/]  - Repository structure overview
 
+    [bold purple]📦 Package Search Commands:[/]
+    • [cyan]package-search-grep[/] - Regex search in package source code
+    • [cyan]package-search-hybrid[/] - Semantic + regex search in packages
+    • [cyan]package-search-read[/] - Read files from packages
+
     [bold magenta]🔧 Utility Commands:[/]
     • [cyan]serve[/]      - Start REST API server
     • [cyan]export[/]     - Export data to JSON files
@@ -766,7 +772,8 @@ def index(
 @app.command("review")
 def review_pr(
     init_config: bool = typer.Option(False, "--init-config", help="Create a default configuration file and exit"),
-    pr_url: str = typer.Argument("", help="GitHub PR URL (https://github.com/owner/repo/pull/123)"),
+    target: str = typer.Argument("", help="GitHub PR URL or local diff (e.g., main..feature, HEAD~3)"),
+    staged: bool = typer.Option(False, "--staged", help="Review staged changes"),
     config: Optional[str] = typer.Option(
         None, "--config", "-c", help="Path to config file (default: ~/.kit/review-config.yaml)"
     ),
@@ -797,8 +804,9 @@ def review_pr(
         None, "--repo-path", help="Path to existing repository (skips cloning, uses current state)"
     ),
 ):
-    """Review a GitHub PR using kit's repository intelligence and AI analysis."""
+    """Review a GitHub PR or local diff using kit's repository intelligence and AI analysis."""
     from kit.pr_review.config import ReviewConfig
+    from kit.pr_review.local_reviewer import LocalDiffReviewer
     from kit.pr_review.reviewer import PRReviewer
 
     if init_config:
@@ -823,15 +831,23 @@ def review_pr(
                 "2. Set KIT_GITHUB_TOKEN and either KIT_ANTHROPIC_TOKEN or KIT_OPENAI_TOKEN environment variables, or"
             )
             typer.echo("3. Update the config file with your actual tokens")
-            typer.echo("\n💡 Then try: kit review --dry-run https://github.com/owner/repo/pull/123")
+            typer.echo("\n💡 Then try:")
+            typer.echo("   - GitHub PR: kit review --dry-run https://github.com/owner/repo/pull/123")
+            typer.echo("   - Local diff: kit review --dry-run main..feature")
             return
         except Exception as e:
             typer.secho(f"❌ Failed to create config: {e}", fg=typer.colors.RED)
             raise typer.Exit(code=1)
 
-    if not pr_url:
-        typer.secho("❌ PR URL is required", fg=typer.colors.RED)
-        typer.echo("\n💡 Example: kit review https://github.com/owner/repo/pull/123")
+    # Handle --staged flag
+    if staged:
+        target = "--staged"
+    elif not target:
+        typer.secho("❌ Target is required", fg=typer.colors.RED)
+        typer.echo("\n💡 Examples:")
+        typer.echo("  - GitHub PR: kit review https://github.com/owner/repo/pull/123")
+        typer.echo("  - Local diff: kit review main..feature")
+        typer.echo("  - Staged changes: kit review --staged")
         typer.echo("💡 Or run: kit review --help")
         raise typer.Exit(code=1)
 
@@ -943,15 +959,32 @@ def review_pr(
             if not plain:  # Only show this message if not in plain mode
                 print("🛠️ Standard mode configured - repository intelligence enabled")
 
-        # Create reviewer and run review
-        if agentic:
-            from kit.pr_review.agentic_reviewer import AgenticPRReviewer
+        # Determine if target is a PR URL or local diff
+        is_pr_url = (
+            isinstance(target, str) and target.startswith("http") and "github.com" in target and "/pull/" in target
+        )
 
-            agentic_reviewer = AgenticPRReviewer(review_config)
-            comment = agentic_reviewer.review_pr_agentic(pr_url)
+        # Create reviewer and run review
+        if is_pr_url:
+            # GitHub PR review
+            if agentic:
+                from kit.pr_review.agentic_reviewer import AgenticPRReviewer
+
+                agentic_reviewer = AgenticPRReviewer(review_config)
+                comment = agentic_reviewer.review_pr_agentic(target)
+            else:
+                standard_reviewer = PRReviewer(review_config)
+                comment = standard_reviewer.review_pr(target)
         else:
-            standard_reviewer = PRReviewer(review_config)
-            comment = standard_reviewer.review_pr(pr_url)
+            # Local diff review
+            if agentic:
+                typer.secho("⚠️  Agentic mode is not yet supported for local diffs", fg=typer.colors.YELLOW)
+                raise typer.Exit(code=1)
+
+            # Use current directory or specified repo path
+            local_repo_path = repo_path or "."
+            local_reviewer = LocalDiffReviewer(review_config, local_repo_path)
+            comment = local_reviewer.review(target)
 
         # Handle output based on mode
         if plain:
@@ -965,8 +998,17 @@ def review_pr(
             typer.echo(comment)
             typer.echo("=" * 60)
         else:
-            # Normal mode: post comment and show success
-            typer.echo("✅ Review completed and comment posted!")
+            # Normal mode: check if there were actually changes to review
+            if comment.strip() == "No changes to review.":
+                typer.echo("No changes to review.")
+            else:
+                # Show the review content by default
+                typer.echo(comment)
+                # Show completion message after the review
+                if is_pr_url:
+                    typer.echo("\n✅ Review completed and comment posted!")
+                else:
+                    typer.echo("\n✅ Review completed!")
 
     except ValueError as e:
         typer.secho(f"❌ Configuration error: {e}", fg=typer.colors.RED)
@@ -1690,6 +1732,184 @@ def search_semantic(
         raise typer.Exit(code=1)
 
 
+@app.command("package-search-grep")
+def package_search_grep_cmd(
+    package: str = typer.Argument(..., help="Package name to search (e.g., 'numpy', 'django')"),
+    pattern: str = typer.Argument(..., help="Regex pattern to search for"),
+    max_results: int = typer.Option(20, "--max-results", "-m", help="Maximum number of results"),
+    file_pattern: Optional[str] = typer.Option(
+        None, "--file-pattern", "-f", help="Filter files by glob pattern (e.g., '*.py')"
+    ),
+    case_sensitive: bool = typer.Option(True, "--case-sensitive/--ignore-case", "-c/-i", help="Case sensitivity"),
+    json_output: bool = typer.Option(False, "--json", "-j", help="Output as JSON"),
+    formatted: bool = typer.Option(
+        False, "--formatted", "-F", help="Output with formatting and emojis (default is plain like grep)"
+    ),
+):
+    """
+    Search package source code using regex patterns (outputs plain text like grep by default).
+
+    Examples:
+        kit package-search-grep numpy "def.*fft"
+        kit package-search-grep fastapi "async def" | head -10
+        kit package-search-grep django "@login_required" -f "*.py"
+        kit package-search-grep requests "class.*Response" --json
+        kit package-search-grep flask "route" --formatted
+    """
+    try:
+        from .package_search import ChromaPackageSearch
+
+        client = ChromaPackageSearch()
+        results = client.grep(
+            package=package,
+            pattern=pattern,
+            max_results=max_results,
+            file_pattern=file_pattern,
+            case_sensitive=case_sensitive,
+        )
+
+        if json_output:
+            typer.echo(json.dumps(results, indent=2))
+        elif formatted:
+            # Formatted output with emojis (opt-in)
+            typer.echo(f"🔍 Found {len(results)} matches in {package}:")
+            for i, result in enumerate(results[:max_results], 1):
+                file_path = result.get("file_path", "unknown")
+                line_num = result.get("line_number", "?")
+                content = result.get("content", "")
+                typer.echo(f"\n{i}. {file_path}:{line_num}")
+                typer.echo(f"   {content[:100]}...")
+        else:
+            # Default plain output like Unix grep: file:line:content
+            for result in results[:max_results]:
+                file_path = result.get("file_path", "unknown")
+                line_num = result.get("line_number", "?")
+                content = result.get("content", "").strip()
+                typer.echo(f"{file_path}:{line_num}:{content}")
+
+    except ValueError as e:
+        handle_cli_error(e, "Package search error", "Check your API key and package name")
+    except Exception as e:
+        handle_cli_error(e, "Unexpected error")
+
+
+@app.command("package-search-hybrid")
+def package_search_hybrid_cmd(
+    package: str = typer.Argument(..., help="Package name to search"),
+    query: str = typer.Argument(..., help="Semantic search query"),
+    regex_filter: Optional[str] = typer.Option(None, "--regex", "-r", help="Optional regex filter"),
+    max_results: int = typer.Option(10, "--max-results", "-m", help="Maximum number of results"),
+    file_pattern: Optional[str] = typer.Option(None, "--file-pattern", "-f", help="Filter files by glob pattern"),
+    json_output: bool = typer.Option(False, "--json", "-j", help="Output as JSON"),
+    formatted: bool = typer.Option(
+        False, "--formatted", "-F", help="Output with formatting and emojis (default is plain)"
+    ),
+):
+    """
+    Semantic search with optional regex filtering in package source code (outputs plain text by default).
+
+    Examples:
+        kit package-search-hybrid numpy "fast fourier transform"
+        kit package-search-hybrid django "authentication middleware" --regex "class.*Middleware"
+        kit package-search-hybrid tensorflow "gradient computation" --formatted
+        kit package-search-hybrid requests "HTTP pooling" --json
+    """
+    try:
+        from .package_search import ChromaPackageSearch
+
+        client = ChromaPackageSearch()
+        results = client.hybrid_search(
+            package=package,
+            query=query,
+            regex_filter=regex_filter,
+            max_results=max_results,
+            file_pattern=file_pattern,
+        )
+
+        if json_output:
+            typer.echo(json.dumps(results, indent=2))
+        elif formatted:
+            # Formatted output with emojis (opt-in)
+            typer.echo(f"🔎 Found {len(results)} relevant snippets in {package}:")
+            for i, result in enumerate(results[:max_results], 1):
+                file_path = result.get("file_path", "unknown")
+                snippet = result.get("snippet", result.get("content", ""))[:200]
+                typer.echo(f"\n{i}. {file_path}")
+                typer.echo(f"   {snippet}...")
+        else:
+            # Default plain output: just file:snippet
+            for result in results[:max_results]:
+                file_path = result.get("file_path", "unknown")
+                snippet = result.get("snippet", result.get("content", ""))[:200].strip()
+                typer.echo(f"{file_path}:{snippet}")
+
+    except ValueError as e:
+        handle_cli_error(e, "Package search error", "Check your API key and package name")
+    except Exception as e:
+        handle_cli_error(e, "Unexpected error")
+
+
+@app.command("package-search-read")
+def package_search_read_cmd(
+    package: str = typer.Argument(..., help="Package name"),
+    file_path: str = typer.Argument(..., help="Path to file within package"),
+    start_line: Optional[int] = typer.Option(None, "--start", "-s", help="Starting line number"),
+    end_line: Optional[int] = typer.Option(None, "--end", "-e", help="Ending line number"),
+    json_output: bool = typer.Option(False, "--json", "-j", help="Output as JSON"),
+    plain: bool = typer.Option(False, "--plain", "-p", help="Output plain text without formatting"),
+):
+    """
+    Read a specific file from a package.
+
+    Examples:
+        kit package-search-read numpy numpy/__init__.py
+        kit package-search-read requests requests/models.py --start 100 --end 200
+        kit package-search-read django django/contrib/auth/middleware.py
+    """
+    try:
+        from .package_search import ChromaPackageSearch
+
+        client = ChromaPackageSearch()
+        content = client.read_file(
+            package=package,
+            file_path=file_path,
+            start_line=start_line,
+            end_line=end_line,
+        )
+
+        if json_output:
+            result = {
+                "package": package,
+                "file_path": file_path,
+                "start_line": start_line,
+                "end_line": end_line,
+                "content": content,
+            }
+            typer.echo(json.dumps(result, indent=2))
+        elif plain:
+            # Plain output: just the content
+            typer.echo(content)
+        else:
+            # Formatted output with header
+            lines = f"{start_line}-{end_line}" if start_line and end_line else "all"
+            typer.echo(f"📄 {package}/{file_path} (lines: {lines})")
+            typer.echo("-" * 60)
+            typer.echo(content)
+
+    except ValueError as e:
+        handle_cli_error(e, "Package search error", "Check your API key, package name, and file path")
+    except httpx.ReadTimeout:
+        typer.secho("⏱️ Request timed out. The Chroma API may be slow for this package.", fg=typer.colors.YELLOW)
+        typer.secho("   Try again with a smaller file or different package.", fg=typer.colors.BRIGHT_BLACK)
+        raise typer.Exit(1)
+    except httpx.RemoteProtocolError as e:
+        typer.secho(f"⚠️ Connection issue: {e}", fg=typer.colors.YELLOW)
+        typer.secho("   The Chroma API may be having issues. Try again later.", fg=typer.colors.BRIGHT_BLACK)
+        raise typer.Exit(1)
+    except Exception as e:
+        handle_cli_error(e, "Unexpected error")
+
+
 def handle_cli_error(error: Exception, error_type: str = "Error", help_text: Optional[str] = None) -> None:
     """Consistent error handling for CLI commands."""
     if isinstance(error, ValueError):
