@@ -6,7 +6,7 @@ from enum import Enum
 from pathlib import Path
 from typing import Dict, List, Optional
 
-import yaml
+import yaml  # type: ignore
 
 
 class LLMProvider(Enum):
@@ -49,8 +49,13 @@ def _detect_provider_from_model(model_name: str) -> Optional[LLMProvider]:
             stripped_model = stripped_model[len(prefix) :]
             break
 
-    # OpenAI model patterns
-    openai_patterns = ["gpt-", "o1-", "text-davinci", "text-curie", "text-babbage", "text-ada"]
+    # OpenAI model patterns (includes GPT-5 mini/nano and O3 models)
+    # Check exact matches first
+    if stripped_model == "o3":
+        return LLMProvider.OPENAI
+
+    # Then check prefix/substring patterns
+    openai_patterns = ["gpt-", "o1-", "o3-", "text-davinci", "text-curie", "text-babbage", "text-ada"]
     if any(pattern in stripped_model for pattern in openai_patterns):
         return LLMProvider.OPENAI
 
@@ -127,7 +132,6 @@ class LLMConfig:
     model: str
     api_key: str
     max_tokens: int = 4000
-    temperature: float = 0.1
     api_base_url: Optional[str] = None  # For local LLMs or custom OpenAI endpoints
 
 
@@ -159,6 +163,13 @@ class ReviewConfig:
     profile_context: Optional[str] = None  # Loaded profile context
     # Existing repository path (skips cloning when provided)
     repo_path: Optional[str] = None  # Path to existing repository to use for analysis
+    # Local review settings
+    save_reviews: bool = False  # Save local reviews to .kit/reviews/
+    llm_provider: Optional[str] = None  # Convenience accessor for llm.provider
+    llm_model: Optional[str] = None  # Convenience accessor for llm.model
+    llm_api_key: Optional[str] = None  # Convenience accessor for llm.api_key
+    llm_api_base_url: Optional[str] = None  # Convenience accessor for llm.api_base_url
+    llm_max_tokens: Optional[int] = None  # Convenience accessor for llm.max_tokens
 
     @classmethod
     def from_file(
@@ -235,7 +246,7 @@ class ReviewConfig:
                 config_api_key = None  # Treat placeholder as missing
             api_key = config_api_key or os.getenv("KIT_ANTHROPIC_TOKEN") or os.getenv("ANTHROPIC_API_KEY")
         elif provider == LLMProvider.GOOGLE:
-            default_model = "gemini-2.5-flash"  # Updated to latest model
+            default_model = "gemini-2.5-flash"
             api_key_env = "KIT_GOOGLE_API_KEY or GOOGLE_API_KEY"
             config_api_key = llm_data.get("api_key")
             if _is_placeholder_token(config_api_key):
@@ -275,7 +286,6 @@ class ReviewConfig:
             model=llm_data.get("model", default_model),
             api_key=str(api_key),
             max_tokens=llm_data.get("max_tokens", 4000),
-            temperature=llm_data.get("temperature", 0.1),
             api_base_url=llm_data.get("api_base_url"),
         )
 
@@ -332,6 +342,13 @@ class ReviewConfig:
             profile=profile,
             profile_context=profile_context,
             repo_path=repo_path,
+            save_reviews=review_data.get("save_reviews", False),
+            # Convenience accessors for LLM config
+            llm_provider=llm_config.provider.value,
+            llm_model=llm_config.model,
+            llm_api_key=llm_config.api_key,
+            llm_api_base_url=llm_config.api_base_url,
+            llm_max_tokens=llm_config.max_tokens,
         )
 
     def create_default_config_file(self, config_path: Optional[str] = None) -> str:
@@ -349,7 +366,6 @@ class ReviewConfig:
                 "model": "claude-sonnet-4-20250514",  # or "gpt-4o", "gemini-2.5-flash"
                 "api_key": "sk-your_api_key_here",
                 "max_tokens": 4000,
-                "temperature": 0.1,
                 # For custom OpenAI compatible providers (e.g., Together AI, OpenRouter, etc.)
                 # "api_base_url": "https://api.together.xyz/v1",  # Example: Together AI
                 # "api_base_url": "https://openrouter.ai/api/v1",  # Example: OpenRouter
@@ -401,7 +417,6 @@ class ReviewConfig:
 #   api_base_url: "http://localhost:11434"  # Default Ollama endpoint
 #   api_key: "ollama"  # Placeholder (Ollama doesn't use API keys)
 #   max_tokens: 2000
-#   temperature: 0.1
 
 # Example Google Gemini configuration:
 # llm:
@@ -409,7 +424,6 @@ class ReviewConfig:
 #   model: "gemini-2.5-flash"  # Or "gemini-2.5-pro" for more complex reasoning, "gemini-2.0-flash-lite" for speed
 #   api_key: "AIzaSy..."  # Get from https://aistudio.google.com/apikey
 #   max_tokens: 4000
-#   temperature: 0.1
 
 # Example OpenAI compatible provider configurations:
 #
@@ -420,7 +434,6 @@ class ReviewConfig:
 #   api_key: "your_together_api_key"
 #   api_base_url: "https://api.together.xyz/v1"
 #   max_tokens: 4000
-#   temperature: 0.1
 #
 # OpenRouter (https://openrouter.ai/):
 # llm:
@@ -429,7 +442,6 @@ class ReviewConfig:
 #   api_key: "your_openrouter_api_key"
 #   api_base_url: "https://openrouter.ai/api/v1"
 #   max_tokens: 4000
-#   temperature: 0.1
 #
 # Local OpenAI API server (e.g., text-generation-webui, vLLM):
 # llm:
@@ -438,7 +450,6 @@ class ReviewConfig:
 #   api_key: "not-used"  # Local servers often don't require API keys
 #   api_base_url: "http://localhost:8000/v1"
 #   max_tokens: 4000
-#   temperature: 0.1
 #
 # Groq (https://groq.com/):
 # llm:
@@ -447,7 +458,6 @@ class ReviewConfig:
 #   api_key: "your_groq_api_key"
 #   api_base_url: "https://api.groq.com/openai/v1"
 #   max_tokens: 4000
-#   temperature: 0.1
 """
 
         with open(config_path, "a") as f:
