@@ -31,7 +31,13 @@ def test_detect_provider_from_model():
     assert _detect_provider_from_model("gpt-4o") == LLMProvider.OPENAI
     assert _detect_provider_from_model("gpt-4.1-nano") == LLMProvider.OPENAI
     assert _detect_provider_from_model("gpt-3.5-turbo") == LLMProvider.OPENAI
+    assert _detect_provider_from_model("gpt-5") == LLMProvider.OPENAI
+    assert _detect_provider_from_model("gpt-5-mini") == LLMProvider.OPENAI
+    assert _detect_provider_from_model("gpt-5-nano") == LLMProvider.OPENAI
     assert _detect_provider_from_model("o1-preview") == LLMProvider.OPENAI
+    assert _detect_provider_from_model("o3") == LLMProvider.OPENAI
+    assert _detect_provider_from_model("o3-mini") == LLMProvider.OPENAI
+    assert _detect_provider_from_model("o3-medium") == LLMProvider.OPENAI
     assert _detect_provider_from_model("text-davinci-003") == LLMProvider.OPENAI
 
     # Anthropic models
@@ -680,7 +686,6 @@ def test_config_custom_openai_provider():
                 "api_key": "together_api_key",
                 "api_base_url": "https://api.together.xyz/v1",
                 "max_tokens": 4000,
-                "temperature": 0.1,
             },
         }
         yaml.dump(config_data, f)
@@ -694,7 +699,6 @@ def test_config_custom_openai_provider():
         assert config.llm.api_base_url == "https://api.together.xyz/v1"
         assert config.llm.model == "meta-llama/Llama-3.3-70B-Instruct-Turbo"
         assert config.llm.max_tokens == 4000
-        assert config.llm.temperature == 0.1
     finally:
         import os
 
@@ -1422,6 +1426,9 @@ def test_helicone_api_integration():
 
     from kit.pr_review.cost_tracker import CostTracker
 
+    # Clear the cache first to ensure test isolation
+    CostTracker._fetch_pricing_with_cache.cache_clear()
+
     # Mock successful API response
     mock_response = MagicMock()
     mock_response.json.return_value = {
@@ -1452,6 +1459,9 @@ def test_helicone_api_integration():
         expected_cost = (1000 / 1_000_000) * 5.0 + (1000 / 1_000_000) * 15.0
         assert abs(tracker.breakdown.llm_cost_usd - expected_cost) < 0.0001
 
+    # Clear cache again to avoid affecting other tests
+    CostTracker._fetch_pricing_with_cache.cache_clear()
+
 
 def test_helicone_api_fallback():
     """Test fallback when Helicone API is unavailable."""
