@@ -15,5 +15,5 @@ def test_get_tool_schemas_basic():
 
     # Spot-check a few known tool names
     tool_names = {s["name"] for s in schemas}
-    for expected in {"open_repository", "search_code", "get_file_tree", "get_file_content"}:
+    for expected in {"open_repository", "grep_code", "get_file_tree", "extract_symbols"}:
         assert expected in tool_names, f"{expected} should be part of tool schema list"
